/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.milaifontanals.jdbc;

import java.io.FileReader;
import java.io.IOException;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Date;
import java.util.Properties;
import java.util.Scanner;

/**
 *
 * @author Usuari
 */
public class MostrarEmpleatsDeDept {

    /**
     * Mostra informació dels empleats.
     *
     * La connexió amb el SGBD s'estableix a partir de dades en fitxer de
     * configuració, que ha de ser un fitxer de propietats (format text) i
     * contenir les propìetats url, usuari, contrasenya
     *
     * @param args Ha de contenir 1 únic argument amb el nom del fitxer de
     * configuració
     */
    public static void main(String[] args) {
        if (args.length != 1) {
            System.out.println("Programa a invocar amb un paràmetre: nom de fitxer \"properties\" amb propietats de connexió");
            return;
        }
        Properties p = new Properties();
        try {
            p.load(new FileReader(args[0]));
        } catch (IOException ex) {
            System.out.println("Problemes en carregar el fitxer de configuració");
            System.out.println("Més info: " + ex.getMessage());
            System.exit(1);
        }
        // p conté les propietats necessàries per la connexió
        String url = p.getProperty("url");
        String usu = p.getProperty("usuari");
        String pwd = p.getProperty("contrasenya");
        if (url == null || usu == null || pwd == null) {
            System.out.println("Manca alguna de les propietats: url, usuari, contrasenya");
            return;
        }
        // Ja tenim les 3 propietats
        // Podem intentar establir connexió
        Connection con = null;
        try {
            con = DriverManager.getConnection(url, usu, pwd);
            System.out.println("Connexió establerta");
            con.setAutoCommit(false);
            System.out.println("Autocommit a false");

            // Objectiu: Mostrar dels empleats (emp_no, cognom, data_alta, comissio)
            // de departament amb codi a introduir per usuari
            // Ho fem amb una consulta parametritzada, preparada prèviament
            // i que executarem tantes vegades com convingui
            PreparedStatement ps
                    = con.prepareStatement("select emp_no, cognom, data_alta, comissio from emp where dept_no=?");

            Scanner sc = new Scanner(System.in);
            while (true) {
                System.out.println("Introdueixi codi de departament (cadena buida per finalitzar)");
                String dada = sc.nextLine();
                if (dada.equals("")) {
                    break;
                }
                try {
//                    ps.setByte(1, Byte.valueOf(dada));
                    ps.setString(1, dada);
                } catch (NumberFormatException ex) {
                    System.out.println("El valor introduït no és vàlid per a codi de departament");
                    continue;
                }
                // Aquí estem segurs que hem emplenat el paràmetre amb un valor numèric vàlid
                System.out.println("Empleats de departament " + dada);

                ResultSet rs = ps.executeQuery();
                boolean trobat = false;
                while (rs.next()) {
                    trobat = true;
                    // Ja s'ha ubicat a la fila següent
                    System.out.print("Empleat de codi " + rs.getShort(1));
                    System.out.print(" - Cognom: " + rs.getString("cognom"));
                    Date d = rs.getDate(3);
                    if (d == null) {
                        System.out.print(" - Data alta: ???");
                    } else {
                        System.out.print(" - Data alta: " + d);
                    }
                    long aux = rs.getLong("comissio");      // Per esbrinar si és null
                    if (rs.wasNull()) {
                        System.out.println(" - Comissio: ???");
                    } else {
                        System.out.println(" - Comissio: " + aux);
                    }
                }
                rs.close();
                if (!trobat) {
                    System.out.println("No hi ha cap empleat");
                }
            }
        } catch (SQLException ex) {
            System.out.println("Excepcio: " + ex.getClass().getName());
            infoError(ex);
        } finally {
            if (con != null) {
                try {
                    con.close();
                    System.out.println("Connexió tancada");
                } catch (SQLException ex) {
                    System.out.println("Excepcio en tancar la connexió: " + ex.getClass().getName());
                    infoError(ex);
                }
            }
        }
    }

    private static void infoError(Throwable aux) {
        do {
            if (aux.getMessage() != null) {
                System.out.println("\t" + aux.getMessage());
            }
            aux = aux.getCause();
        } while (aux != null);

    }

}
