package org.milaifontanals.jdbc;

import java.io.FileReader;
import java.io.IOException;
import java.sql.*;
import java.util.Properties;

public class P01_Exemple_ResultSet_CRUD {

    public static void main(String[] args) {
        Properties p = new Properties();
        try {
            p.load(new FileReader(args[0]));
        } catch (IOException ex) {
            System.out.println("Problemes en carregar el fitxer de configuració");
            System.out.println("Més info: " + ex.getMessage());
            System.exit(1);
        }
        // p conté les propietats necessàries per la connexió
        String url = p.getProperty("url");
        String usu = p.getProperty("usuari");
        String pwd = p.getProperty("contrasenya");
        if (url == null || usu == null || pwd == null) {
            System.out.println("Manca alguna de les propietats: url, usuari, contrasenya");
            System.exit(1);
        }
        // Ja tenim les 3 propietats
        Connection con = null;
        try {
            con = DriverManager.getConnection(url, usu, pwd);
            System.out.println("Connexió establerta");
            con.setAutoCommit(false);   // Per defecte, tota connexió JDBC és amb AutoCommit(true)

            Statement st = con.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE,
                    ResultSet.CONCUR_UPDATABLE);
            ResultSet rs = st.executeQuery("select dept_no, dnom, loc "
                    + "from dept");
            // ATENCIÓ!!! Per a que un ResultSet sigui modificable, cal haver 
            //            creat el Statement adequadament i, a més,
            //            NO es pot fer "select * " i només sobre una taula!!!

            System.out.println("Recorregut pels departaments, modificant el nom:");
            int i = 0;
            // BUCLE 1: Recorregut pels departaments, modificant-ne el nom
            while (rs.next()) {
                // Mostrem el departament recuperat
                showDept(rs);
                // Modifiquem el nom (i altres columnes si interessés
                rs.updateString("dnom", "Fantasma " + (++i));
                rs.updateRow();
                // Tornem a mostrar el departament
                showDept(rs);
            }
            // BUCLE 2: Afegim varies departaments via el ResultSet
            for (int j = 61; j <= 63 ; j++) {
                System.out.println("Afegim departament " + j);
                rs.moveToInsertRow();
                rs.updateInt("dept_no", j);
                rs.updateString("dnom", "Dept " + j);
                rs.updateString("loc", "Pobl " + j);
                rs.insertRow();
                showDept(rs);
            }
            // Eliminem algun departament via el ResultSet
            // Eliminarem el 40 per què no té cap empleat... i es pot eliminar
            System.out.println("Eliminem departament 40:");
            rs.beforeFirst();
            while (rs.next()) {
                if (rs.getInt("dept_no") == 40) {
                    // PUNT3
                    rs.deleteRow();
                }
            }
            // Nou recorregut
            System.out.println("Mostrem de nou tot el ResultSet");
            rs.beforeFirst();
            while (rs.next()) {
                showDept(rs);
            }
            con.commit();
        } catch (SQLException sqle) {
            sqle.printStackTrace();
            try {
                con.rollback();
            } catch (SQLException sss) {
                sss.printStackTrace();
            }
            System.exit(-1);
        } finally {
            try {
                if (con != null) {
                    con.rollback();
                    con.close();
                }
            } catch (SQLException sqle) {
                sqle.printStackTrace();
            }
        }
    }

    private static void showDept(ResultSet rs) throws SQLException {
        String cadena = "Departament: ";
        cadena = cadena + rs.getString("dept_no");
        cadena = cadena + " - " + rs.getString("dnom");
        String localitat = " - " + rs.getString("loc");
        if (rs.wasNull()) {
            localitat = "";
        }
        cadena = cadena + localitat;
        System.out.println(cadena);
    }
}
